@@ -1,3 +1,6 @@
+# Copyright Contributors to the Amundsen project.
+# SPDX-License-Identifier: Apache-2.0
+
 import ast
 import importlib
 import logging
@@ -12,13 +15,15 @@ from flask import Flask, Blueprint
 from flask_restful import Api
 
 from metadata_service.api.column import ColumnDescriptionAPI
-from metadata_service.api.dashboard import DashboardDetailAPI, DashboardDescriptionAPI, DashboardTagAPI
+from metadata_service.api.dashboard import (DashboardDetailAPI, DashboardDescriptionAPI,
+                                            DashboardTagAPI, DashboardBadgeAPI)
 from metadata_service.api.healthcheck import healthcheck
 from metadata_service.api.popular_tables import PopularTablesAPI
 from metadata_service.api.system import Neo4jDetailAPI
 from metadata_service.api.table \
-    import TableDetailAPI, TableOwnerAPI, TableTagAPI, TableDescriptionAPI, TableDashboardAPI
+    import TableDetailAPI, TableOwnerAPI, TableTagAPI, TableBadgeAPI, TableDescriptionAPI, TableDashboardAPI
 from metadata_service.api.tag import TagAPI
+from metadata_service.api.badge import BadgeAPI
 from metadata_service.api.user import (UserDetailAPI, UserFollowAPI,
                                        UserFollowsAPI, UserOwnsAPI,
                                        UserOwnAPI, UserReadsAPI)
@@ -83,12 +88,16 @@ def create_app(*, config_module_class: str) -> Flask:
 
     api = Api(api_bp)
 
-    api.add_resource(PopularTablesAPI, '/popular_tables/')
+    api.add_resource(PopularTablesAPI,
+                     '/popular_tables/',
+                     '/popular_tables/<path:user_id>')
     api.add_resource(TableDetailAPI, '/table/<path:table_uri>')
     api.add_resource(TableDescriptionAPI,
                      '/table/<path:id>/description')
     api.add_resource(TableTagAPI,
                      '/table/<path:id>/tag/<tag>')
+    api.add_resource(TableBadgeAPI,
+                     '/table/<path:id>/badge/<badge>')
     api.add_resource(TableOwnerAPI,
                      '/table/<path:table_uri>/owner/<owner>')
     api.add_resource(TableDashboardAPI,
@@ -99,6 +108,8 @@ def create_app(*, config_module_class: str) -> Flask:
                      '/latest_updated_ts')
     api.add_resource(TagAPI,
                      '/tags/')
+    api.add_resource(BadgeAPI,
+                     '/badges/')
     api.add_resource(UserDetailAPI,
                      '/user',
                      '/user/<path:id>')
@@ -118,6 +129,8 @@ def create_app(*, config_module_class: str) -> Flask:
                      '/dashboard/<path:id>/description')
     api.add_resource(DashboardTagAPI,
                      '/dashboard/<path:id>/tag/<tag>')
+    api.add_resource(DashboardBadgeAPI,
+                     '/dashboard/<path:id>/badge/<badge>')
     app.register_blueprint(api_bp)
 
     if app.config.get('SWAGGER_ENABLED'):
